@@ -1,18 +1,15 @@
 from __future__ import absolute_import
 
-import types
 from time import time, sleep
-from functools import wraps
 from contextlib import contextmanager
 from unittest import TestCase as BaseTestCase
-from unittest.case import SkipTest
+from threading import Event
 
 from six import with_metaclass
 from pyuv import Loop, Async, Idle
 
 from thriftworker import state
 from thriftworker.app import ThriftWorker
-from thriftworker.utils.env import detect_environment
 from thriftworker.utils.loop import greenlet_delegate
 
 TIMEOUT = 5.0
@@ -62,7 +59,7 @@ class StartStopLoopMixin(CustomAppMixin):
         self.addCleanup(hub.stop)
 
     def wakeup_loop(self):
-        event = self.app.env.RealEvent()
+        event = Event()
         handles = []
 
         def idle_cb(handle):
@@ -80,27 +77,6 @@ class StartStopLoopMixin(CustomAppMixin):
         event.wait()
 
 
-def custom_env_needed(env):
-    """Skip test if current environment differ from needed."""
-
-    def inner_decorator(test_item):
-        reason = 'Current environment differ from needed!'
-
-        if env != detect_environment():
-            if not isinstance(test_item, (type, types.ClassType)):
-                @wraps(test_item)
-                def skip_wrapper(*args, **kwargs):
-                    raise SkipTest(reason)
-                test_item = skip_wrapper
-
-            test_item.__unittest_skip__ = True
-            test_item.__unittest_skip_why__ = reason
-
-        return test_item
-
-    return inner_decorator
-
-
 class GreenMeta(type):
 
     def __new__(meta, classname, bases, attrs):
