@@ -1,13 +1,11 @@
 from __future__ import absolute_import
 
 from thriftworker.workers.threads import ThreadsWorker
-from thriftworker.constants import DEFAULT_ENV
-from thriftworker.tests.utils import TestCase, custom_env_needed
+from thriftworker.tests.utils import TestCase
 
 from .utils import WorkerMixin
 
 
-@custom_env_needed(DEFAULT_ENV)
 class TestThreadsWorker(WorkerMixin, TestCase):
 
     Worker = ThreadsWorker
