@@ -1,4 +1,6 @@
 from __future__ import absolute_import
 
 from .counter import Counter
+from .counters import Counters
 from .timer import Timer
+from .timers import Timers
